==> pdt-SDK-1.0.3.zip: org/eclipse/php/internal/ui/wizards/operations/PHPModelCreationOperation.java <==
/*******************************************************************************
 * Copyright (c) 2006 Zend Corporation and IBM Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Zend and IBM - Initial implementation
 *******************************************************************************/
package org.eclipse.php.internal.ui.wizards.operations;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.WorkspaceJob;
import org.eclipse.core.runtime.*;
import org.eclipse.php.internal.core.Logger;
import org.eclipse.php.internal.core.PHPCoreConstants;
import org.eclipse.php.internal.core.preferences.CorePreferenceConstants.Keys;
import org.eclipse.php.internal.core.project.IIncludePathEntry;
import org.eclipse.php.internal.core.project.PHPNature;
import org.eclipse.php.internal.core.project.options.PHPProjectOptions;
import org.eclipse.php.internal.core.project.properties.handlers.PhpVersionProjectPropertyHandler;
import org.eclipse.php.internal.core.project.properties.handlers.UseAspTagsHandler;
import org.eclipse.php.internal.ui.wizards.WizardPageFactory;
import org.eclipse.wst.common.frameworks.datamodel.AbstractDataModelOperation;
import org.eclipse.wst.common.frameworks.datamodel.IDataModel;
import org.eclipse.wst.common.frameworks.internal.operations.IProjectCreationPropertiesNew;

public class PHPModelCreationOperation extends AbstractDataModelOperation implements IProjectCreationPropertiesNew {

	// List of WizardPageFactory(s) added trough the phpWizardPages extention point
	private List /* WizardPageFactory */wizardPageFactories = new ArrayList();

	public PHPModelCreationOperation(IDataModel dataModel, List wizardPageFactories) {
		super(dataModel);
		this.wizardPageFactories = wizardPageFactories;
	}

	public PHPModelCreationOperation(IDataModel dataModel) {
		super(dataModel);
	}

	public IStatus execute(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {
		try {
			IProgressMonitor subMonitor = new SubProgressMonitor(monitor, IProgressMonitor.UNKNOWN);
			final IProjectDescription desc = (IProjectDescription) model.getProperty(PROJECT_DESCRIPTION);
			final IProject project = (IProject) model.getProperty(PROJECT);
			if (!project.exists()) {
				project.create(desc, subMonitor);
			}

			if (monitor.isCanceled())
				throw new OperationCanceledException();
			subMonitor = new SubProgressMonitor(monitor, IProgressMonitor.UNKNOWN);

			project.open(subMonitor);

			// For every page added to the projectCreationWizard, call its execute method
			// Here the project settings should be stored into the preferences
			// This action needs to happen here, after the project has been created and opened
			// and before setNatureIds is called

			// NOTE: project opening can take time if it's built from existing source (bug #205444)
			// Thus the next should run as the same type of workspace job.
			WorkspaceJob job = new WorkspaceJob("Saving project options") {

				@Override
				public IStatus runInWorkspace(IProgressMonitor monitor) throws CoreException {
					for (Iterator iter = wizardPageFactories.iterator(); iter.hasNext();) {
						WizardPageFactory pageFactory = (WizardPageFactory) iter.next();
						pageFactory.execute();
					}

					String[] natureIds = (String[]) model.getProperty(PROJECT_NATURES);
					if (null != natureIds) {
						desc.setNatureIds(natureIds);
						project.setDescription(desc, monitor);
					}

					PHPNature nature = (PHPNature) project.getNature(PHPNature.ID);
					PHPProjectOptions options = nature.getOptions();
					String defaultEncodeing = model.getStringProperty(PHPCoreConstants.PHPOPTION_DEFAULT_ENCODING);
					options.setOption(PHPCoreConstants.PHPOPTION_DEFAULT_ENCODING, defaultEncodeing);
					String context = model.getStringProperty(PHPCoreConstants.PHPOPTION_CONTEXT_ROOT);
					options.setOption(PHPCoreConstants.PHPOPTION_CONTEXT_ROOT, context);
					IIncludePathEntry[] includePath = (IIncludePathEntry[]) model.getProperty(PHPCoreConstants.PHPOPTION_INCLUDE_PATH);
					options.setRawIncludePath(includePath, new SubProgressMonitor(monitor, includePath.length));
					// options.saveChanges(monitor);

					if (model.isPropertySet(Keys.PHP_VERSION)) {
						String version = model.getStringProperty(Keys.PHP_VERSION);
						PhpVersionProjectPropertyHandler.setVersion(version, project);
						boolean useASPTags = model.getBooleanProperty(Keys.EDITOR_USE_ASP_TAGS);
						UseAspTagsHandler.setUseAspTagsAsPhp(useASPTags, project);
					}

					return Status.OK_STATUS;
				}
			};
			job.setRule(project.getWorkspace().getRoot());
			job.schedule();
		} catch (CoreException e) {
			Logger.logException(e);
		} finally {
			monitor.done();
		}
		if (monitor.isCanceled())
			throw new OperationCanceledException();
		return OK_STATUS;
	}

	public boolean canUndo() {
		return false;
	}

	public boolean canRedo() {
		return false;
	}

}

==> pdt-SDK-1.0.5.zip: org/eclipse/php/internal/ui/wizards/operations/PHPModelCreationOperation.java <==
/*******************************************************************************
 * Copyright (c) 2006 Zend Corporation and IBM Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Zend and IBM - Initial implementation
 *******************************************************************************/
package org.eclipse.php.internal.ui.wizards.operations;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.WorkspaceJob;
import org.eclipse.core.runtime.*;
import org.eclipse.php.internal.core.Logger;
import org.eclipse.php.internal.core.PHPCoreConstants;
import org.eclipse.php.internal.core.preferences.CorePreferenceConstants.Keys;
import org.eclipse.php.internal.core.project.IIncludePathEntry;
import org.eclipse.php.internal.core.project.PHPNature;
import org.eclipse.php.internal.core.project.options.PHPProjectOptions;
import org.eclipse.php.internal.core.project.properties.handlers.PhpVersionProjectPropertyHandler;
import org.eclipse.php.internal.core.project.properties.handlers.UseAspTagsHandler;
import org.eclipse.php.internal.ui.wizards.WizardPageFactory;
import org.eclipse.wst.common.frameworks.datamodel.AbstractDataModelOperation;
import org.eclipse.wst.common.frameworks.datamodel.IDataModel;
import org.eclipse.wst.common.frameworks.internal.operations.IProjectCreationPropertiesNew;
import org.eclipse.wst.jsdt.core.IJavaScriptProject;
import org.eclipse.wst.jsdt.core.JavaScriptCore;
import org.eclipse.wst.jsdt.web.core.internal.project.JsWebNature;

public class PHPModelCreationOperation extends AbstractDataModelOperation implements IProjectCreationPropertiesNew {

	// List of WizardPageFactory(s) added trough the phpWizardPages extention point
	private List /* WizardPageFactory */wizardPageFactories = new ArrayList();

	public PHPModelCreationOperation(IDataModel dataModel, List wizardPageFactories) {
		super(dataModel);
		this.wizardPageFactories = wizardPageFactories;
	}

	public PHPModelCreationOperation(IDataModel dataModel) {
		super(dataModel);
	}

	public IStatus execute(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {
		try {
			IProgressMonitor subMonitor = new SubProgressMonitor(monitor, IProgressMonitor.UNKNOWN);
			final IProjectDescription desc = (IProjectDescription) model.getProperty(PROJECT_DESCRIPTION);
			final IProject project = (IProject) model.getProperty(PROJECT);
			if (!project.exists()) {
				project.create(desc, subMonitor);
			}

			if (monitor.isCanceled())
				throw new OperationCanceledException();
			subMonitor = new SubProgressMonitor(monitor, IProgressMonitor.UNKNOWN);

			project.open(subMonitor);

			// For every page added to the projectCreationWizard, call its execute method
			// Here the project settings should be stored into the preferences
			// This action needs to happen here, after the project has been created and opened
			// and before setNatureIds is called

			// NOTE: project opening can take time if it's built from existing source (bug #205444)
			// Thus the next should run as the same type of workspace job.
			WorkspaceJob job = new WorkspaceJob("Saving project options") {

				@Override
				public IStatus runInWorkspace(IProgressMonitor monitor) throws CoreException {
					for (Iterator iter = wizardPageFactories.iterator(); iter.hasNext();) {
						WizardPageFactory pageFactory = (WizardPageFactory) iter.next();
						pageFactory.execute();
					}

					String[] natureIds = (String[]) model.getProperty(PROJECT_NATURES);
					if (null != natureIds) {
						desc.setNatureIds(natureIds);
						project.setDescription(desc, monitor);
					}
					
					// add JS support if desired
					boolean addJavaScript = model.getBooleanProperty(PHPCoreConstants.ADD_JS_NATURE);
					if (addJavaScript) {
						JsWebNature nature = new JsWebNature(project,null);
						nature.configure();
					}

					PHPNature nature = (PHPNature) project.getNature(PHPNature.ID);
					PHPProjectOptions options = nature.getOptions();
					String defaultEncodeing = model.getStringProperty(PHPCoreConstants.PHPOPTION_DEFAULT_ENCODING);
					options.setOption(PHPCoreConstants.PHPOPTION_DEFAULT_ENCODING, defaultEncodeing);
					String context = model.getStringProperty(PHPCoreConstants.PHPOPTION_CONTEXT_ROOT);
					options.setOption(PHPCoreConstants.PHPOPTION_CONTEXT_ROOT, context);
					IIncludePathEntry[] includePath = (IIncludePathEntry[]) model.getProperty(PHPCoreConstants.PHPOPTION_INCLUDE_PATH);
					options.setRawIncludePath(includePath, new SubProgressMonitor(monitor, includePath.length));
					// options.saveChanges(monitor);

					if (model.isPropertySet(Keys.PHP_VERSION)) {
						String version = model.getStringProperty(Keys.PHP_VERSION);
						PhpVersionProjectPropertyHandler.setVersion(version, project);
						boolean useASPTags = model.getBooleanProperty(Keys.EDITOR_USE_ASP_TAGS);
						UseAspTagsHandler.setUseAspTagsAsPhp(useASPTags, project);
					}

					if (addJavaScript) {
						// do not create src folder for javascript
						final IJavaScriptProject scriptProject = JavaScriptCore.create(project);
						final org.eclipse.wst.jsdt.core.IIncludePathEntry[] rawIncludepath = scriptProject.getRawIncludepath();
						scriptProject.setRawIncludepath(getTrimmedIncludePath(rawIncludepath), new NullProgressMonitor());
					}
					return Status.OK_STATUS;
				}
			};
			job.setRule(project.getWorkspace().getRoot());
			job.schedule();
		} catch (CoreException e) {
			Logger.logException(e);
		} finally {
			monitor.done();
		}
		if (monitor.isCanceled())
			throw new OperationCanceledException();
		return OK_STATUS;
	}

	/**
	 * Remove the src folder - leaves only the library entries
	 * @param rawIncludepath
	 * @return 
	 */
	private org.eclipse.wst.jsdt.core.IIncludePathEntry[] getTrimmedIncludePath(final org.eclipse.wst.jsdt.core.IIncludePathEntry[] rawIncludepath) {
		ArrayList<org.eclipse.wst.jsdt.core.IIncludePathEntry> newIncludePath = new ArrayList<org.eclipse.wst.jsdt.core.IIncludePathEntry>();
		for (int i = 0; i < rawIncludepath.length; i++) {
			org.eclipse.wst.jsdt.core.IIncludePathEntry includePathEntry = (org.eclipse.wst.jsdt.core.IIncludePathEntry) rawIncludepath[i];
			if (includePathEntry.getEntryKind() != org.eclipse.wst.jsdt.core.IIncludePathEntry.CPE_SOURCE) {
				newIncludePath.add(includePathEntry);
			}
		}
		return newIncludePath.toArray(new org.eclipse.wst.jsdt.core.IIncludePathEntry[newIncludePath.size()]);
	}

	public boolean canUndo() {
		return false;
	}

	public boolean canRedo() {
		return false;
	}

}
